Docker config.json authentication parser
This module parses the Docker config file format used by Docker and other container tools to store registry credentials. The config file is typically located at ~/.docker/config.json.
Structs
- Docker
Config Auth - Docker config.json authentication manager